@@ -4,9 +4,9 @@ use strict;
 use parent 'BorderStyleBase';
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-24'; # DATE
+our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %BORDER = (
     v => 2,
@@ -14,7 +14,7 @@ our %BORDER = (
     chars => [
         ['l','q','q','k'], # 0
         ['x',' ','x'],     # 1
-        ['x',' ',' ','x', ' ',' '], # 2
+        ['x',' ',' ','x', ' ',' ','q','q'], # 2
         ['x',' ','x'],     # 3
         ['t','q','q','u', 'q','q','q','q'], # 4
         ['m','q','q','j'], # 5
@@ -37,7 +37,7 @@ BorderStyle::BoxChar::SingleLineOuterOnly - Single line border with box-drawing
 
 =head1 VERSION
 
-This document describes version 0.009 of BorderStyle::BoxChar::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2022-01-24.
+This document describes version 0.010 of BorderStyle::BoxChar::SingleLineOuterOnly (from Perl distribution BorderStyles-Standard), released on 2022-01-26.
 
 =head1 SYNOPSIS
 
