@@ -5,9 +5,9 @@ use parent 'BorderStyleBase';
 use utf8;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-24'; # DATE
+our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %BORDER = (
     v => 2,
@@ -15,7 +15,7 @@ our %BORDER = (
     chars => [
         ['','','',''],     # 0
         ['','',''],        # 1
-        ['','','','', '',''],     # 2
+        ['','','','', '','','',''],     # 2
         ['','',''],        # 3
         ['','─','─','', '','','',''],   # 4
         ['','','',''],     # 5
@@ -38,7 +38,7 @@ BorderStyle::UTF8::None - No borders, but data row separator is still drawn usin
 
 =head1 VERSION
 
-This document describes version 0.009 of BorderStyle::UTF8::None (from Perl distribution BorderStyles-Standard), released on 2022-01-24.
+This document describes version 0.010 of BorderStyle::UTF8::None (from Perl distribution BorderStyles-Standard), released on 2022-01-26.
 
 =head1 SYNOPSIS
 
