@@ -5,9 +5,9 @@ use parent 'BorderStyleBase';
 use utf8;
 
 our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2022-01-24'; # DATE
+our $DATE = '2022-01-26'; # DATE
 our $DIST = 'BorderStyles-Standard'; # DIST
-our $VERSION = '0.009'; # VERSION
+our $VERSION = '0.010'; # VERSION
 
 our %BORDER = (
     v => 2,
@@ -15,7 +15,7 @@ our %BORDER = (
     chars => [
         ['┏','━','┳','┓'], # 0
         ['┃','┃','┃'],     # 1
-        ['┡','━','╇','┩', '┯','┻'], # 2
+        ['┡','━','╇','┩', '┯','┻','├','┤'], # 2
         ['│','│','│'],     # 3
         ['├','─','┼','┤', '┬','┴','├','┤'], # 4
         ['└','─','┴','┘'], # 5
@@ -41,7 +41,7 @@ BorderStyle::UTF8::SingleLineBoldHeader - Single-line border (header box bold) w
 
 =head1 VERSION
 
-This document describes version 0.009 of BorderStyle::UTF8::SingleLineBoldHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-24.
+This document describes version 0.010 of BorderStyle::UTF8::SingleLineBoldHeader (from Perl distribution BorderStyles-Standard), released on 2022-01-26.
 
 =head1 SYNOPSIS
 
